@@ -1,10 +1,10 @@
-// Copyright © 2021 Rouven Spreckels <rs@qu1x.dev>
+// Copyright © 2021-2022 Rouven Spreckels <rs@qu1x.dev>
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
 // file, You can obtain one at https://mozilla.org/MPL/2.0/.
 
-use super::SimdBits;
+use super::{Select, SimdBits};
 use core::simd::{LaneCount, Mask, Simd, SupportedLaneCount};
 
 impl<const LANES: usize> SimdBits<u64, LANES> for Simd<u64, LANES>
@@ -52,3 +52,13 @@ where
 		self.saturating_sub(other)
 	}
 }
+
+impl<const LANES: usize> Select<Mask<i64, LANES>> for Simd<u64, LANES>
+where
+	LaneCount<LANES>: SupportedLaneCount,
+{
+	#[inline]
+	fn select(mask: Mask<i64, LANES>, true_values: Self, false_values: Self) -> Self {
+		mask.select(true_values, false_values)
+	}
+}
